<?php

namespace Inventory\Adjustment\Policies;

use Litepie\User\Contracts\UserPolicy;
use Inventory\Adjustment\Models\Adjustment;

class AdjustmentPolicy
{

    /**
     * Determine if the given user can view the adjustment.
     *
     * @param UserPolicy $user
     * @param Adjustment $adjustment
     *
     * @return bool
     */
    public function view(UserPolicy $user, Adjustment $adjustment)
    {
        if ($user->canDo('adjustment.adjustment.view') && $user->isAdmin()) {
            return true;
        }

        return $adjustment->user_id == user_id() && $adjustment->user_type == user_type();
    }

    /**
     * Determine if the given user can create a adjustment.
     *
     * @param UserPolicy $user
     * @param Adjustment $adjustment
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('adjustment.adjustment.create');
    }

    /**
     * Determine if the given user can update the given adjustment.
     *
     * @param UserPolicy $user
     * @param Adjustment $adjustment
     *
     * @return bool
     */
    public function update(UserPolicy $user, Adjustment $adjustment)
    {
        if ($user->canDo('adjustment.adjustment.edit') && $user->isAdmin()) {
            return true;
        }

        return $adjustment->user_id == user_id() && $adjustment->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given adjustment.
     *
     * @param UserPolicy $user
     * @param Adjustment $adjustment
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Adjustment $adjustment)
    {
        return $adjustment->user_id == user_id() && $adjustment->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given adjustment.
     *
     * @param UserPolicy $user
     * @param Adjustment $adjustment
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Adjustment $adjustment)
    {
        if ($user->canDo('adjustment.adjustment.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given adjustment.
     *
     * @param UserPolicy $user
     * @param Adjustment $adjustment
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Adjustment $adjustment)
    {
        if ($user->canDo('adjustment.adjustment.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
