<?php

namespace Inventory\Adjustment\Policies;

use Litepie\User\Contracts\UserPolicy;
use Inventory\Adjustment\Models\Item;

class ItemPolicy
{

    /**
     * Determine if the given user can view the item.
     *
     * @param UserPolicy $user
     * @param Item $item
     *
     * @return bool
     */
    public function view(UserPolicy $user, Item $item)
    {
        if ($user->canDo('adjustment.item.view') && $user->isAdmin()) {
            return true;
        }

        return $item->user_id == user_id() && $item->user_type == user_type();
    }

    /**
     * Determine if the given user can create a item.
     *
     * @param UserPolicy $user
     * @param Item $item
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('adjustment.item.create');
    }

    /**
     * Determine if the given user can update the given item.
     *
     * @param UserPolicy $user
     * @param Item $item
     *
     * @return bool
     */
    public function update(UserPolicy $user, Item $item)
    {
        if ($user->canDo('adjustment.item.edit') && $user->isAdmin()) {
            return true;
        }

        return $item->user_id == user_id() && $item->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given item.
     *
     * @param UserPolicy $user
     * @param Item $item
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Item $item)
    {
        return $item->user_id == user_id() && $item->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given item.
     *
     * @param UserPolicy $user
     * @param Item $item
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Item $item)
    {
        if ($user->canDo('adjustment.item.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given item.
     *
     * @param UserPolicy $user
     * @param Item $item
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Item $item)
    {
        if ($user->canDo('adjustment.item.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
