<?php

namespace Inventory\Adjustment\Policies;

use Litepie\User\Contracts\UserPolicy;
use Inventory\Adjustment\Models\Reason;

class ReasonPolicy
{

    /**
     * Determine if the given user can view the reason.
     *
     * @param UserPolicy $user
     * @param Reason $reason
     *
     * @return bool
     */
    public function view(UserPolicy $user, Reason $reason)
    {
        if ($user->canDo('adjustment.reason.view') && $user->isAdmin()) {
            return true;
        }

        return $reason->user_id == user_id() && $reason->user_type == user_type();
    }

    /**
     * Determine if the given user can create a reason.
     *
     * @param UserPolicy $user
     * @param Reason $reason
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('adjustment.reason.create');
    }

    /**
     * Determine if the given user can update the given reason.
     *
     * @param UserPolicy $user
     * @param Reason $reason
     *
     * @return bool
     */
    public function update(UserPolicy $user, Reason $reason)
    {
        if ($user->canDo('adjustment.reason.edit') && $user->isAdmin()) {
            return true;
        }

        return $reason->user_id == user_id() && $reason->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given reason.
     *
     * @param UserPolicy $user
     * @param Reason $reason
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Reason $reason)
    {
        return $reason->user_id == user_id() && $reason->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given reason.
     *
     * @param UserPolicy $user
     * @param Reason $reason
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Reason $reason)
    {
        if ($user->canDo('adjustment.reason.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given reason.
     *
     * @param UserPolicy $user
     * @param Reason $reason
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Reason $reason)
    {
        if ($user->canDo('adjustment.reason.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
