<?php

namespace Inventory\Adjustment\Providers;

use Illuminate\Foundation\Support\Providers\RouteServiceProvider as ServiceProvider;
use Illuminate\Routing\Router;
use Inventory\Adjustment\Models\Adjustment;
use Request;
use Route;

class RouteServiceProvider extends ServiceProvider
{
    /**
     * This namespace is applied to the controller routes in your routes file.
     *
     * In addition, it is set as the URL generator's root namespace.
     *
     * @var string
     */
    protected $namespace = 'Inventory\Adjustment\Http\Controllers';

    /**
     * Define your route model bindings, pattern filters, etc.
     *
     * @param   \Illuminate\Routing\Router  $router
     * @return void
     */
    public function boot()
    {
        parent::boot();

        if (Request::is('*/adjustment/adjustment/*')) {
            Route::bind('adjustment', function ($adjustment) {
                $adjustmentrepo = $this->app->make('Inventory\Adjustment\Interfaces\AdjustmentRepositoryInterface');
                return $adjustmentrepo->findorNew($adjustment);
            });
        }
        if (Request::is('*/adjustment/reason/*')) {
            Route::bind('reason', function ($reason) {
                $reasonrepo = $this->app->make('Inventory\Adjustment\Interfaces\ReasonRepositoryInterface');
                return $reasonrepo->findorNew($reason);
            });
        }
        if (Request::is('*/adjustment/item/*')) {
            Route::bind('item', function ($item) {
                $itemrepo = $this->app->make('Inventory\Adjustment\Interfaces\ItemRepositoryInterface');
                return $itemrepo->findorNew($item);
            });
        }

    }

    /**
     * Define the routes for the package.
     *
     * @return void
     */
    public function map()
    {
        $this->mapWebRoutes();
    }

    /**
     * Define the "web" routes for the package.
     *
     * These routes all receive session state, CSRF protection, etc.
     *
     * @return void
     */
    protected function mapWebRoutes()
    {   
        Route::group([
            'middleware' => 'web',
            'namespace'  => $this->namespace,
        ], function ($router) {
            require (__DIR__ . '/../../routes/web.php');
        });
    }

}
